@@ -32,9 +32,8 @@
 #include <cogl/cogl-color.h>
 #include <cogl/cogl-matrix.h>
 #include <cogl/cogl-texture.h>
-#include <glib.h>
 
-G_BEGIN_DECLS
+COGL_BEGIN_DECLS
 
 #ifdef COGL_ENABLE_EXPERIMENTAL_API
 
@@ -173,7 +172,7 @@ cogl_pipeline_set_layer_texture (CoglPipeline *pipeline,
 void
 cogl_pipeline_set_layer_null_texture (CoglPipeline *pipeline,
                                       int layer_index,
-                                      CoglTextureType texure_type);
+                                      CoglTextureType texture_type);
 
 /**
  * cogl_pipeline_get_layer_texture:
@@ -208,7 +207,7 @@ cogl_pipeline_remove_layer (CoglPipeline *pipeline,
  * @layer_index: Specifies the layer you want define a combine function for
  * @blend_string: A <link linkend="cogl-Blend-Strings">Cogl blend string</link>
  *    describing the desired texture combine function.
- * @error: A #GError that may report parse errors or lack of GPU/driver
+ * @error: A #CoglError that may report parse errors or lack of GPU/driver
  *   support. May be %NULL, in which case a warning will be printed out if an
  *   error is encountered.
  *
@@ -256,7 +255,7 @@ cogl_pipeline_remove_layer (CoglPipeline *pipeline,
  *   <varlistentry>
  *     <term>CONSTANT</term>
  *     <listitem>Use the color from the constant given with
- *     cogl_pipeline_set_layer_constant()</listitem>
+ *     cogl_pipeline_set_layer_combine_constant()</listitem>
  *   </varlistentry>
  *   <varlistentry>
  *     <term>PRIMARY</term>
@@ -279,7 +278,8 @@ cogl_pipeline_remove_layer (CoglPipeline *pipeline,
  *   </programlisting></informalexample>
  *   <para>This could be used to cross-fade between two images, using
  *   the alpha component of a constant as the interpolator. The constant
- *   color is given by calling cogl_pipeline_set_layer_constant.</para>
+ *   color is given by calling
+ *   cogl_pipeline_set_layer_combine_constant().</para>
  *   <informalexample><programlisting>
  *   RGBA = INTERPOLATE (PREVIOUS, TEXTURE, CONSTANT[A])
  *   </programlisting></informalexample>
@@ -299,7 +299,7 @@ CoglBool
 cogl_pipeline_set_layer_combine (CoglPipeline *pipeline,
 				 int           layer_index,
 				 const char   *blend_string,
-                                 GError      **error);
+                                 CoglError      **error);
 
 /**
  * cogl_pipeline_set_layer_combine_constant:
@@ -360,6 +360,11 @@ cogl_pipeline_get_n_layers (CoglPipeline *pipeline);
  * Changes the decimation and interpolation filters used when a texture is
  * drawn at other scales than 100%.
  *
+ * <note>It is an error to pass anything other than
+ * %COGL_PIPELINE_FILTER_NEAREST or %COGL_PIPELINE_FILTER_LINEAR as
+ * magnification filters since magnification doesn't ever need to
+ * reference values stored in the mipmap chain.</note>
+ *
  * Since: 1.10
  * Stability: unstable
  */
@@ -416,7 +421,7 @@ cogl_pipeline_get_layer_mag_filter (CoglPipeline *pipeline,
  * @pipeline: A #CoglPipeline object
  * @layer_index: the layer number to change.
  * @enable: whether to enable point sprite coord generation.
- * @error: A return location for a GError, or NULL to ignore errors.
+ * @error: A return location for a CoglError, or NULL to ignore errors.
  *
  * When rendering points, if @enable is %TRUE then the texture
  * coordinates for this layer will be replaced with coordinates that
@@ -425,7 +430,7 @@ cogl_pipeline_get_layer_mag_filter (CoglPipeline *pipeline,
  * have 1.0,1.0. If @enable is %FALSE then the coordinates will be
  * fixed for the entire point.
  *
- * This function will only work if %COGL_FEATURE_POINT_SPRITE is
+ * This function will only work if %COGL_FEATURE_ID_POINT_SPRITE is
  * available. If the feature is not available then the function will
  * return %FALSE and set @error.
  *
@@ -437,7 +442,7 @@ CoglBool
 cogl_pipeline_set_layer_point_sprite_coords_enabled (CoglPipeline *pipeline,
                                                      int           layer_index,
                                                      CoglBool      enable,
-                                                     GError      **error);
+                                                     CoglError      **error);
 
 /**
  * cogl_pipeline_get_layer_point_sprite_coords_enabled:
@@ -603,6 +608,6 @@ cogl_pipeline_add_layer_snippet (CoglPipeline *pipeline,
 
 #endif /* COGL_ENABLE_EXPERIMENTAL_API */
 
-G_END_DECLS
+COGL_END_DECLS
 
 #endif /* __COGL_PIPELINE_LAYER_STATE_H__ */
