@@ -155,6 +155,8 @@ _cogl_renderer_free (CoglRenderer *renderer)
 {
   const CoglWinsysVtable *winsys = _cogl_renderer_get_winsys (renderer);
 
+  _cogl_closure_list_disconnect_all (&renderer->idle_closures);
+
   if (winsys)
     winsys->renderer_disconnect (renderer);
 
@@ -168,6 +170,8 @@ _cogl_renderer_free (CoglRenderer *renderer)
                    NULL);
   g_slist_free (renderer->event_filters);
 
+  g_array_free (renderer->poll_fds, TRUE);
+
   g_free (renderer);
 }
 
@@ -181,10 +185,22 @@ cogl_renderer_new (void)
   renderer->connected = FALSE;
   renderer->event_filters = NULL;
 
+  renderer->poll_fds = g_array_new (FALSE, TRUE, sizeof (CoglPollFD));
+
+  _cogl_list_init (&renderer->idle_closures);
+
 #ifdef COGL_HAS_XLIB_SUPPORT
   renderer->xlib_enable_event_retrieval = TRUE;
 #endif
 
+#ifdef COGL_HAS_WIN32_SUPPORT
+  renderer->win32_enable_event_retrieval = TRUE;
+#endif
+
+#ifdef COGL_HAS_EGL_PLATFORM_WAYLAND_SUPPORT
+  renderer->wayland_enable_event_dispatch = TRUE;
+#endif
+
   return _cogl_renderer_object_new (renderer);
 }
 
