@@ -150,9 +150,10 @@ _cogl_texture_2d_allocate (CoglTexture *tex,
 }
 
 CoglTexture2D *
-cogl_texture_2d_new_from_bitmap (CoglBitmap *bmp,
-                                 CoglPixelFormat internal_format,
-                                 CoglError **error)
+_cogl_texture_2d_new_from_bitmap (CoglBitmap *bmp,
+                                  CoglPixelFormat internal_format,
+                                  CoglBool can_convert_in_place,
+                                  CoglError **error)
 {
   CoglContext *ctx;
 
@@ -178,9 +179,43 @@ cogl_texture_2d_new_from_bitmap (CoglBitmap *bmp,
 
   return ctx->driver_vtable->texture_2d_new_from_bitmap (bmp,
                                                          internal_format,
+                                                         can_convert_in_place,
                                                          error);
 }
 
+CoglTexture2D *
+cogl_texture_2d_new_from_bitmap (CoglBitmap *bmp,
+                                 CoglPixelFormat internal_format,
+                                 CoglError **error)
+{
+  return _cogl_texture_2d_new_from_bitmap (bmp, internal_format, FALSE, error);
+}
+
+CoglTexture2D *
+cogl_texture_2d_new_from_file (CoglContext *ctx,
+                               const char *filename,
+                               CoglPixelFormat internal_format,
+                               CoglError **error)
+{
+  CoglBitmap *bmp;
+  CoglTexture2D *tex_2d = NULL;
+
+  _COGL_RETURN_VAL_IF_FAIL (error == NULL || *error == NULL, NULL);
+
+  bmp = _cogl_bitmap_from_file (ctx, filename, error);
+  if (bmp == NULL)
+    return NULL;
+
+  tex_2d = _cogl_texture_2d_new_from_bitmap (bmp,
+                                             internal_format,
+                                             TRUE, /* can convert in-place */
+                                             error);
+
+  cogl_object_unref (bmp);
+
+  return tex_2d;
+}
+
 CoglTexture2D *
 cogl_texture_2d_new_from_data (CoglContext *ctx,
                                int width,
